@@ -8,8 +8,7 @@ import (
 )
 
 type Connection struct {
-	props properties.Properties
-	env   runtime.Environment
+	base
 
 	runtime.Connection
 }
@@ -24,8 +23,8 @@ func (c *Connection) Template() string {
 
 func (c *Connection) Enabled() bool {
 	types := c.props.GetString(Type, "wifi|ethernet")
-	connectionTypes := strings.Split(types, "|")
-	for _, connectionType := range connectionTypes {
+	connectionTypes := strings.SplitSeq(types, "|")
+	for connectionType := range connectionTypes {
 		network, err := c.env.Connection(runtime.ConnectionType(connectionType))
 		if err != nil {
 			continue
@@ -35,8 +34,3 @@ func (c *Connection) Enabled() bool {
 	}
 	return false
 }
-
-func (c *Connection) Init(props properties.Properties, env runtime.Environment) {
-	c.props = props
-	c.env = env
-}
