@@ -16,6 +16,10 @@ import (
 	"github.com/jandedobbeleer/oh-my-posh/src/template"
 )
 
+const (
+	regexPrefix = "re:"
+)
+
 type Folder struct {
 	Name    string
 	Path    string
@@ -570,12 +574,16 @@ func (pt *Path) setMappedLocations() {
 			continue
 		}
 
+		if !strings.HasPrefix(location, regexPrefix) {
+			location = pt.normalize(location)
+		}
+
 		// When two templates resolve to the same key, the values are compared in ascending order and the latter is taken.
-		if v, exist := mappedLocations[pt.normalize(location)]; exist && value <= v {
+		if v, exist := mappedLocations[location]; exist && value <= v {
 			continue
 		}
 
-		mappedLocations[pt.normalize(location)] = value
+		mappedLocations[location] = value
 	}
 
 	pt.mappedLocations = mappedLocations
@@ -609,8 +617,38 @@ func (pt *Path) replaceMappedLocations(inputPath string) (string, string) {
 		return strings.NewReplacer("<", "<<>", ">", "<>>").Replace(path)
 	}
 
+	handleRegex := func(key string) (string, bool) {
+		if !strings.HasPrefix(key, regexPrefix) {
+			return "", false
+		}
+
+		input := strings.ReplaceAll(inputPath, `\`, `/`)
+		pattern := key[len(regexPrefix):]
+
+		// Add (?i) at the start of the pattern for case-insensitive matching on Windows
+		if pt.windowsPath || (pt.env.IsWsl() && strings.HasPrefix(input, "/mnt/")) {
+			pattern = "(?i)" + pattern
+		}
+
+		match, OK := regex.FindStringMatch(pattern, input, 1)
+		if !OK {
+			return "", false
+		}
+
+		// Replace the first match with the mapped location.
+		input = strings.Replace(input, match, pt.mappedLocations[key], 1)
+		input = path.Clean(input)
+
+		return input, true
+	}
+
 	for _, key := range keys {
+		if input, OK := handleRegex(key); OK {
+			return pt.parsePath(input)
+		}
+
 		keyRoot, keyRelative := pt.parsePath(key)
+
 		matchSubFolders := strings.HasSuffix(keyRelative, pt.pathSeparator+"*")
 
 		if matchSubFolders {
@@ -804,7 +842,7 @@ func (pt *Path) splitPath() Folders {
 		return folders
 	}
 
-	elements := strings.Split(pt.relative, pt.pathSeparator)
+	elements := strings.SplitSeq(pt.relative, pt.pathSeparator)
 	folderFormatMap := pt.makeFolderFormatMap()
 	currentPath := pt.root
 
@@ -814,7 +852,7 @@ func (pt *Path) splitPath() Folders {
 
 	var display bool
 
-	for _, element := range elements {
+	for element := range elements {
 		currentPath += element
 
 		if format := folderFormatMap[currentPath]; len(format) != 0 {
