@@ -15,6 +15,7 @@ const (
 	PromptMark
 	RPrompt
 	CursorPositioning
+	Async
 )
 
 type Features []Feature
@@ -34,8 +35,6 @@ func (f Features) Lines(shell string) Lines {
 			code = feature.Bash()
 		case ELVISH:
 			code = feature.Elvish()
-		case TCSH:
-			code = feature.Tcsh()
 		case FISH:
 			code = feature.Fish()
 		case CMD:
